@@ -121,6 +121,13 @@ options:
             private_ip_address:
                 description:
                     - Private IP address for the IP configuration.
+            private_ip_address_version:
+                description:
+                    - The version of the IP configuration.
+                choices:
+                    - IPv4
+                    - IPv6
+                default: IPv4
             private_ip_allocation_method:
                 description:
                     - Private IP allocation method.
@@ -146,6 +153,12 @@ options:
                     - List of existing load-balancer backend address pools to associate with the network interface.
                     - Can be written as a resource ID.
                     - Also can be a dict of I(name) and I(load_balancer).
+            application_gateway_backend_address_pools:
+                description:
+                    - List of existing application gateway backend address pools to associate with the network interface.
+                    - Can be written as a resource ID.
+                    - Also can be a dict of I(name) and I(application_gateway).
+                version_added: "1.10.0"
             primary:
                 description:
                     - Whether the IP configuration is the primary one in the list.
@@ -273,6 +286,21 @@ EXAMPLES = '''
               - name: backendaddrpool1
                 load_balancer: loadbalancer001
 
+    - name: Create network interface attached to application gateway backend address pool
+      azure_rm_networkinterface:
+        name: nic-appgw
+        resource_group: myResourceGroup
+        virtual_network: vnet001
+        subnet_name: subnet001
+        create_with_security_group: false
+        public_ip: false
+        ip_configurations:
+          - name: default
+            primary: true
+            application_gateway_backend_address_pools:
+              - name: myApplicationGatewayBackendAddressPool
+                application_gateway: myApplicationGateway
+
     - name: Create a network interface in accelerated networking mode
       azure_rm_networkinterface:
         name: nic005
@@ -367,13 +395,25 @@ state:
                     sample: default
                 load_balancer_backend_address_pools:
                     description:
-                        - List of existing load-balancer backend address pools to associate with the network interface.
+                        - List of existing load-balancer backend address pools associated with the network interface.
                     type: list
+                application_gateway_backend_address_pools:
+                    description:
+                        - List of existing application gateway backend address pool resource IDs associated with the network interface.
+                    type: list
+                    version_added: "1.10.0"
+                    sample: ["/subscriptions/xxx/resourceGroups/myResourceGroup/providers/Microsoft.Network/applicationGateways/myGateway/
+                        backendAddressPools/myBackendAddressPool"]
                 private_ip_address:
                     description:
                         - Private IP address for the IP configuration.
                     type: str
                     sample: "10.1.0.10"
+                private_ip_address_version:
+                    description:
+                        - The version of the IP configuration.
+                    type: str
+                    sample: "IPv4"
                 private_ip_allocation_method:
                     description:
                         - Private IP allocation method.
@@ -474,11 +514,14 @@ def nic_to_dict(nic):
         dict(
             name=config.name,
             private_ip_address=config.private_ip_address,
+            private_ip_address_version=config.private_ip_address_version,
             private_ip_allocation_method=config.private_ip_allocation_method,
             subnet=subnet_to_dict(config.subnet),
-            primary=config.primary,
+            primary=config.primary if config.primary else False,
             load_balancer_backend_address_pools=([item.id for item in config.load_balancer_backend_address_pools]
                                                  if config.load_balancer_backend_address_pools else None),
+            application_gateway_backend_address_pools=([item.id for item in config.application_gateway_backend_address_pools]
+                                                       if config.application_gateway_backend_address_pools else None),
             public_ip_address=dict(
                 id=config.public_ip_address.id,
                 name=azure_id_to_dict(config.public_ip_address.id).get('publicIPAddresses'),
@@ -518,10 +561,12 @@ def nic_to_dict(nic):
 ip_configuration_spec = dict(
     name=dict(type='str', required=True),
     private_ip_address=dict(type='str'),
+    private_ip_address_version=dict(type='str', choices=['IPv4', 'IPv6'], default='IPv4'),
     private_ip_allocation_method=dict(type='str', choices=['Dynamic', 'Static'], default='Dynamic'),
     public_ip_address_name=dict(type='str', aliases=['public_ip_address', 'public_ip_name']),
     public_ip_allocation_method=dict(type='str', choices=['Dynamic', 'Static'], default='Dynamic'),
     load_balancer_backend_address_pools=dict(type='list'),
+    application_gateway_backend_address_pools=dict(type='list'),
     primary=dict(type='bool', default=False),
     application_security_groups=dict(type='list', elements='raw')
 )
@@ -741,12 +786,17 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
                     self.network_models.NetworkInterfaceIPConfiguration(
                         private_ip_allocation_method=ip_config.get('private_ip_allocation_method'),
                         private_ip_address=ip_config.get('private_ip_address'),
+                        private_ip_address_version=ip_config.get('private_ip_address_version'),
                         name=ip_config.get('name'),
                         subnet=subnet,
                         public_ip_address=self.get_or_create_public_ip_address(ip_config),
                         load_balancer_backend_address_pools=([self.network_models.BackendAddressPool(id=self.backend_addr_pool_id(bap_id))
                                                               for bap_id in ip_config.get('load_balancer_backend_address_pools')]
                                                              if ip_config.get('load_balancer_backend_address_pools') else None),
+                        application_gateway_backend_address_pools=([self.network_models.ApplicationGatewayBackendAddressPool
+                                                                    (id=self.gateway_backend_addr_pool_id(bap_id))
+                                                                    for bap_id in ip_config.get('application_gateway_backend_address_pools')]
+                                                                   if ip_config.get('application_gateway_backend_address_pools') else None),
                         primary=ip_config.get('primary'),
                         application_security_groups=([self.network_models.ApplicationSecurityGroup(id=asg_id)
                                                       for asg_id in ip_config.get('application_security_groups')]
@@ -846,6 +896,20 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
                                    child_name_1=name)
         return val
 
+    def gateway_backend_addr_pool_id(self, val):
+        if isinstance(val, dict):
+            appgw = val.get('application_gateway', None)
+            name = val.get('name', None)
+            if appgw and name:
+                return resource_id(subscription=self.subscription_id,
+                                   resource_group=self.resource_group,
+                                   namespace='Microsoft.Network',
+                                   type='applicationGateways',
+                                   name=appgw,
+                                   child_type_1='backendAddressPools',
+                                   child_name_1=name)
+        return val
+
     def construct_ip_configuration_set(self, raw):
         configurations = [str(dict(
             private_ip_allocation_method=to_native(item.get('private_ip_allocation_method')),
@@ -855,6 +919,9 @@ class AzureRMNetworkInterface(AzureRMModuleBase):
             load_balancer_backend_address_pools=(set([to_native(self.backend_addr_pool_id(id))
                                                       for id in item.get('load_balancer_backend_address_pools')])
                                                  if item.get('load_balancer_backend_address_pools') else None),
+            application_gateway_backend_address_pools=(set([to_native(self.gateway_backend_addr_pool_id(id))
+                                                           for id in item.get('application_gateway_backend_address_pools')])
+                                                       if item.get('application_gateway_backend_address_pools') else None),
             application_security_groups=(set([to_native(asg_id) for asg_id in item.get('application_security_groups')])
                                          if item.get('application_security_groups') else None),
             name=to_native(item.get('name'))
