@@ -484,6 +484,10 @@ class TestIosAclsModule(TestIosModule):
                 10 permit tcp 198.51.100.0 0.0.0.255 any eq 22 log (tag = testLog)
                 20 deny icmp 192.0.2.0 0.0.0.255 192.0.3.0 0.0.0.255 echo dscp ef ttl eq 10
                 30 deny icmp object-group test_network_og any echo dscp ef ttl eq 10
+            Reflexive IP access list MIRROR
+                permit tcp host 0.0.0.0 eq 22 host 192.168.0.1 eq 50200 (2 matches) (time left 123)
+                permit tcp host 0.0.0.0 eq 22 host 192.168.0.1 eq 50201 (2 matches) (time left 345)
+                permit tcp host 0.0.0.0 eq 22 host 192.168.0.1 eq 50202 (2 matches) (time left 678)
             IPv6 access list R1_TRAFFIC
                 deny tcp any eq www any eq telnet ack dscp af11 sequence 10
             """
@@ -730,7 +734,7 @@ class TestIosAclsModule(TestIosModule):
     def test_ios_acls_parsed(self):
         set_module_args(
             dict(
-                running_config="IPv6 access list R1_TRAFFIC\ndeny tcp any eq www any eq telnet ack dscp af11 sequence 10",
+                running_config="IPv6 access list R1_TRAFFIC\ndeny tcp any eq www any range 10 20 ack dscp af11 sequence 10",
                 state="parsed",
             )
         )
@@ -743,7 +747,9 @@ class TestIosAclsModule(TestIosModule):
                             {
                                 "destination": {
                                     "any": True,
-                                    "port_protocol": {"eq": "telnet"},
+                                    "port_protocol": {
+                                        "range": {"start": 10, "end": 20}
+                                    },
                                 },
                                 "dscp": "af11",
                                 "grant": "deny",
@@ -764,6 +770,44 @@ class TestIosAclsModule(TestIosModule):
         ]
         self.assertEqual(parsed_list, result["parsed"])
 
+    def test_ios_acls_parsed_matches(self):
+        set_module_args(
+            dict(
+                running_config="""Standard IP access list R1_TRAFFIC\n10 permit 10.11.12.13 (2 matches)\n
+                40 permit 128.0.0.0, wildcard bits 63.255.255.255 (2 matches)""",
+                state="parsed",
+            )
+        )
+        result = self.execute_module(changed=False)
+        parsed_list = [
+            {
+                "afi": "ipv4",
+                "acls": [
+                    {
+                        "name": "R1_TRAFFIC",
+                        "acl_type": "standard",
+                        "aces": [
+                            {
+                                "sequence": 10,
+                                "grant": "permit",
+                                "source": {"address": "10.11.12.13"},
+                            },
+                            {
+                                "sequence": 40,
+                                "grant": "permit",
+                                "source": {
+                                    "address": "128.0.0.0",
+                                    "wildcard_bits": "63.255.255.255",
+                                },
+                            },
+                        ],
+                    }
+                ],
+            }
+        ]
+        print(result)
+        self.assertEqual(parsed_list, result["parsed"])
+
     def test_ios_acls_overridden_remark(self):
         self.execute_show_command.return_value = dedent(
             """\
@@ -1015,7 +1059,7 @@ class TestIosAclsModule(TestIosModule):
                                             wildcard_bits="0.0.0.255",
                                         ),
                                         tos=dict(max_reliability=True),
-                                        fragments=10,
+                                        enable_fragments=True,
                                     ),
                                     dict(
                                         remarks=["extended ACL remark"],
@@ -1047,7 +1091,7 @@ class TestIosAclsModule(TestIosModule):
         result = self.execute_module(changed=True)
         commands = [
             "ip access-list extended 113",
-            "deny 198.51.100.0 0.0.0.255 198.51.101.0 0.0.0.255 fragments 10 tos max-reliability",
+            "deny 198.51.100.0 0.0.0.255 198.51.101.0 0.0.0.255 fragments tos max-reliability",
             "permit 198.51.101.0 0.0.0.255 198.51.102.0 0.0.0.255 log check tos 119",
             "remark extended ACL remark",
             "ip access-list standard 23",
