@@ -1,6 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
+# Copyright: (c) 2021, Anvitha Jain (@anvitha-jain) <anvjain@cisco.com>
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
@@ -18,6 +19,7 @@ description:
 - Manage External EPG subnets in schema templates on Cisco ACI Multi-Site.
 author:
 - Devarshi Shah (@devarshishah3)
+- Anvitha Jain (@anvitha-jain)
 version_added: '0.0.8'
 options:
   schema:
@@ -39,15 +41,21 @@ options:
     description:
     - The IP range in CIDR notation.
     type: str
-    required: true
   scope:
     description:
-    - The scope of the subnet.
+    - The scope parameter contains two sections 1. Route Control and 2. External EPG Classification.
+    - The existing Route Control parameters are C(export-rtctrl) for Export Route Control, C(import-rtctrl) for Import Route Control
+    - and C(shared-rtctrl) for Shared Route Control
+    - The existing External EPG Classification parameters are C(import-security) for External Subnets for External EPG
+    - and C(shared-security) for Shared Security Import
+    - The  C(shared-security) for Shared Security Import can only be used when External Subnets for External EPG is present
     type: list
     elements: str
   aggregate:
     description:
-    - The aggregate option for the subnet.
+    - The aggregate option aggregates shared routes for the subnet.
+    - Use C(shared-rtctrl) to add Aggregate Shared Routes
+    - The C(shared-rtctrl) option can only be used when scope parameter Shared Route Control in the Route Control section is selected.
     type: list
     elements: str
   state:
@@ -126,7 +134,7 @@ def main():
         template=dict(type='str', required=True),
         external_epg=dict(type='str', required=True),
         state=dict(type='str', default='present', choices=['absent', 'present', 'query']),
-        subnet=dict(type='str', required=True),
+        subnet=dict(type='str'),
         scope=dict(type='list', elements='str', default=[]),
         aggregate=dict(type='list', elements='str', default=[]),
     )
@@ -151,11 +159,7 @@ def main():
     mso = MSOModule(module)
 
     # Get schema
-    schema_obj = mso.get_obj('schemas', displayName=schema)
-    if not schema_obj:
-        mso.fail_json(msg="Provided schema '{0}' does not exist".format(schema))
-
-    schema_path = 'schemas/{id}'.format(**schema_obj)
+    schema_id, schema_path, schema_obj = mso.query_schema(schema)
 
     # Get template
     templates = [t.get('name') for t in schema_obj.get('templates')]
