@@ -25,6 +25,8 @@ module: nxos_feature
 extends_documentation_fragment:
 - cisco.nxos.nxos
 short_description: Manage features in NX-OS switches.
+notes:
+- Limited Support for Cisco MDS
 description:
 - Offers ability to enable and disable features in NX-OS.
 version_added: 1.0.0
@@ -80,6 +82,7 @@ from ansible.module_utils.connection import ConnectionError
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos import (
     load_config,
     run_commands,
+    get_config,
 )
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos import (
     get_capabilities,
@@ -121,6 +124,17 @@ def get_available_features(feature, module):
                 ):
                     available_features[feature] = state
 
+    # certain configurable features do not
+    # show up in the output of "show feature"
+    # but appear in running-config when set
+    run_cfg = get_config(module, flags=["| include ^feature"])
+    for item in re.findall(r"feature\s(.*)", run_cfg):
+        if item not in available_features:
+            available_features[item] = "enabled"
+
+    if "fabric forwarding" not in available_features:
+        available_features["fabric forwarding"] = "disabled"
+
     return available_features
 
 
