@@ -216,7 +216,6 @@ def find_object_by_name(content, name, obj_type, folder=None, recurse=True):
 
 
 def find_cluster_by_name(content, cluster_name, datacenter=None):
-
     if datacenter and hasattr(datacenter, 'hostFolder'):
         folder = datacenter.hostFolder
     else:
@@ -303,8 +302,12 @@ def find_dvs_by_name(content, switch_name, folder=None):
     return find_object_by_name(content, switch_name, [vim.DistributedVirtualSwitch], folder=folder)
 
 
-def find_hostsystem_by_name(content, hostname):
-    return find_object_by_name(content, hostname, [vim.HostSystem])
+def find_hostsystem_by_name(content, hostname, datacenter=None):
+    if datacenter and hasattr(datacenter, 'hostFolder'):
+        folder = datacenter.hostFolder
+    else:
+        folder = content.rootFolder
+    return find_object_by_name(content, hostname, [vim.HostSystem], folder=folder)
 
 
 def find_resource_pool_by_name(content, resource_pool_name):
@@ -554,6 +557,12 @@ def gather_vm_facts(content, vm):
         facts['current_snapshot'] = snapshot_facts['current_snapshot']
 
     facts['vnc'] = get_vnc_extraconfig(vm)
+
+    # Gather vTPM information
+    facts['tpm_info'] = {
+        'tpm_present': vm.summary.config.tpmPresent if hasattr(vm.summary.config, 'tpmPresent') else None,
+        'provider_id': vm.config.keyId.providerId.id if vm.config.keyId else None
+    }
     return facts
 
 
@@ -592,7 +601,8 @@ def deserialize_snapshot_obj(obj):
             'name': obj.name,
             'description': obj.description,
             'creation_time': obj.createTime,
-            'state': obj.state}
+            'state': obj.state,
+            'quiesced': obj.quiesced}
 
 
 def list_snapshots_recursively(snapshots):
@@ -917,6 +927,8 @@ def set_vm_power_state(content, vm, state, force, timeout=0, answers=None):
     requested states. force is forceful
     """
     facts = gather_vm_facts(content, vm)
+    if state == 'present':
+        state = 'poweredon'
     expected_state = state.replace('_', '').replace('-', '').lower()
     current_state = facts['hw_power_status'].lower()
     result = dict(
@@ -1048,11 +1060,11 @@ def option_diff(options, current_options, truthy_strings_as_bool=True):
     for option_key, option_value in options.items():
         if truthy_strings_as_bool and is_boolean(option_value):
             option_value = VmomiSupport.vmodlTypes['bool'](is_truthy(option_value))
-        elif isinstance(option_value, int):
+        elif type(option_value) is int:
             option_value = VmomiSupport.vmodlTypes['int'](option_value)
-        elif isinstance(option_value, float):
+        elif type(option_value) is float:
             option_value = VmomiSupport.vmodlTypes['float'](option_value)
-        elif isinstance(option_value, str):
+        elif type(option_value) is str:
             option_value = VmomiSupport.vmodlTypes['string'](option_value)
 
         if option_key not in current_options_dict or current_options_dict[option_key] != option_value:
@@ -1383,16 +1395,17 @@ class PyVmomi(object):
             return []
 
     # Hosts related functions
-    def find_hostsystem_by_name(self, host_name):
+    def find_hostsystem_by_name(self, host_name, datacenter=None):
         """
         Find Host by name
         Args:
             host_name: Name of ESXi host
+            datacenter: (optional) Datacenter of ESXi resides
 
         Returns: True if found
 
         """
-        return find_hostsystem_by_name(self.content, hostname=host_name)
+        return find_hostsystem_by_name(self.content, hostname=host_name, datacenter=datacenter)
 
     def get_all_host_objs(self, cluster_name=None, esxi_host_name=None):
         """
