@@ -3,7 +3,7 @@
 
 #
 # Dell EMC OpenManage Ansible Modules
-# Version 3.0.0
+# Version 3.4.0
 # Copyright (C) 2019-2021 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
@@ -33,11 +33,15 @@ options:
     default: 'view'
   span_depth:
     type: int
-    description: Span Depth.
+    description:
+      - Number of spans in the RAID configuration.
+      - I(span_depth) is required for C(create) and its value depends on I(volume_type).
     default: 1
   span_length:
     type: int
-    description: Span Length.
+    description:
+      - Number of disks in a span.
+      - I(span_length) is required for C(create) and its value depends on I(volume_type).
     default: 1
   number_dedicated_hot_spare:
     type: int
@@ -482,6 +486,8 @@ def main():
                         changed = False
                         module.exit_json(msg=storage_status.get('Message', ""),
                                          changed=changed, storage_status=storage_status)
+                elif storage_status.get("Status") == "Failed":
+                    module.fail_json(msg=storage_status.get("Message"))
                 else:
                     module.fail_json(msg="Failed to perform storage operation")
     except (ImportError, ValueError, RuntimeError, TypeError) as e:
