@@ -105,55 +105,55 @@ options:
                 suboptions:
                     name:
                         type: str
-                        description: no description
+                        description: 'Name.'
                     vdom:
                         type: str
-                        description: no description
+                        description: 'Vdom.'
             arp-intf:
                 type: str
-                description: no description
+                description: 'Select an interface from available options that will reply to ARP requests. (If blank, any is selected).'
             arp-reply:
                 type: str
-                description: no description
+                description: 'Enable/disable replying to ARP requests when an IP Pool is added to a policy (default = enable).'
                 choices:
                     - 'disable'
                     - 'enable'
             associated-interface:
                 type: str
-                description: no description
+                description: 'Associated interface name.'
             block-size:
                 type: int
-                description: no description
+                description: 'Number of addresses in a block (64 to 4096, default = 128).'
             comments:
                 type: str
-                description: no description
+                description: 'Comment.'
             endip:
                 type: str
-                description: no description
+                description: 'Final IPv4 address (inclusive) in the range for the address pool (format xxx.xxx.xxx.xxx, Default: 0.0.0.0).'
             num-blocks-per-user:
                 type: int
-                description: no description
+                description: 'Number of addresses blocks that can be used by a user (1 to 128, default = 8).'
             pba-timeout:
                 type: int
-                description: no description
+                description: 'Port block allocation timeout (seconds).'
             permit-any-host:
                 type: str
-                description: no description
+                description: 'Enable/disable full cone NAT.'
                 choices:
                     - 'disable'
                     - 'enable'
             source-endip:
                 type: str
-                description: no description
+                description: 'Final IPv4 address (inclusive) in the range of the source addresses to be translated (format xxx.xxx.xxx.xxx, Default: 0.0.0.0).'
             source-startip:
                 type: str
-                description: no description
+                description: 'First IPv4 address (inclusive) in the range of the source addresses to be translated (format xxx.xxx.xxx.xxx, Default: 0.0.0.0).'
             startip:
                 type: str
-                description: no description
+                description: 'First IPv4 address (inclusive) in the range for the address pool (format xxx.xxx.xxx.xxx, Default: 0.0.0.0).'
             type:
                 type: str
-                description: no description
+                description: 'IP pool type (overload, one-to-one, fixed port range, or port block allocation).'
                 choices:
                     - 'overload'
                     - 'one-to-one'
@@ -162,43 +162,43 @@ options:
                     - 'cgn-resource-allocation'
             cgn-block-size:
                 type: int
-                description: no description
+                description: 'Number of ports in a block(64 to 4096 in unit of 64, default = 128).'
             cgn-client-endip:
                 type: str
-                description: no description
+                description: 'Final client IPv4 address (inclusive) (format xxx.xxx.xxx.xxx, Default: 0.0.0.0).'
             cgn-client-startip:
                 type: str
-                description: no description
+                description: 'First client IPv4 address (inclusive) (format xxx.xxx.xxx.xxx, Default: 0.0.0.0).'
             cgn-fixedalloc:
                 type: str
-                description: no description
+                description: 'Enable/disable fixed-allocation mode.'
                 choices:
                     - 'disable'
                     - 'enable'
             cgn-overload:
                 type: str
-                description: no description
+                description: 'Enable/disable overload mode.'
                 choices:
                     - 'disable'
                     - 'enable'
             cgn-port-end:
                 type: int
-                description: no description
+                description: 'Ending public port can be allocated.'
             cgn-port-start:
                 type: int
-                description: no description
+                description: 'Starting public port can be allocated.'
             cgn-spa:
                 type: str
-                description: no description
+                description: 'Enable/disable single port allocation mode.'
                 choices:
                     - 'disable'
                     - 'enable'
             utilization-alarm-clear:
                 type: int
-                description: no description
+                description: 'Pool utilization alarm clear threshold (40-100).'
             utilization-alarm-raise:
                 type: int
-                description: no description
+                description: 'Pool utilization alarm raise threshold (50-100).'
             endport:
                 type: int
                 description: 'Final port number (inclusive) in the range for the address pool (Default: 65533).'
@@ -212,7 +212,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -221,48 +221,40 @@ EXAMPLES = '''
       ansible_httpapi_validate_certs: False
       ansible_httpapi_port: 443
    tasks:
-    - name: Configure IPv4 IP pools.
+    - name: Configure dynamic mappings of IPv4 IP pool
       fmgr_firewall_ippool_dynamicmapping:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         ippool: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         ippool: 'ansible-test' # name
+         state: present
          firewall_ippool_dynamicmapping:
             _scope:
               -
-                  name: <value of string>
-                  vdom: <value of string>
-            arp-intf: <value of string>
-            arp-reply: <value in [disable, enable]>
-            associated-interface: <value of string>
-            block-size: <value of integer>
-            comments: <value of string>
-            endip: <value of string>
-            num-blocks-per-user: <value of integer>
-            pba-timeout: <value of integer>
-            permit-any-host: <value in [disable, enable]>
-            source-endip: <value of string>
-            source-startip: <value of string>
-            startip: <value of string>
-            type: <value in [overload, one-to-one, fixed-port-range, ...]>
-            cgn-block-size: <value of integer>
-            cgn-client-endip: <value of string>
-            cgn-client-startip: <value of string>
-            cgn-fixedalloc: <value in [disable, enable]>
-            cgn-overload: <value in [disable, enable]>
-            cgn-port-end: <value of integer>
-            cgn-port-start: <value of integer>
-            cgn-spa: <value in [disable, enable]>
-            utilization-alarm-clear: <value of integer>
-            utilization-alarm-raise: <value of integer>
-            endport: <value of integer>
-            port-per-user: <value of integer>
-            startport: <value of integer>
-
+                  name: FGT_AWS # need a valid device name
+                  vdom: root # need a valid vdom name under the device
+            comments: 'ansible-comment'
+            endip: '222.222.222.253'
+            startip: '222.222.222.0'
+            type: overload #<value in [overload, one-to-one, fixed-port-range, ...]>
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the dynamic mappings of IPv4 IP pool
+      fmgr_fact:
+        facts:
+            selector: 'firewall_ippool_dynamicmapping'
+            params:
+                adom: 'ansible'
+                ippool: 'ansible-test' # name
+                dynamic_mapping: ''
 '''
 
 RETURN = '''
@@ -309,6 +301,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -748,6 +745,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
