@@ -1,6 +1,6 @@
 #!/usr/bin/python
 from __future__ import absolute_import, division, print_function
-# Copyright 2019-2020 Fortinet, Inc.
+# Copyright 2019-2021 Fortinet, Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -44,6 +44,19 @@ notes:
       the conditions to fail or succeed with parameters rc_failed and rc_succeeded
 
 options:
+    enable_log:
+        description: Enable/Disable logging for task
+        required: false
+        type: bool
+        default: false
+    proposed_method:
+        description: The overridden method for the underlying Json RPC request
+        required: false
+        type: str
+        choices:
+          - update
+          - set
+          - add
     bypass_validation:
         description: only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters
         required: false
@@ -79,7 +92,7 @@ options:
         type: dict
         suboptions:
             alert-destination:
-                description: no description
+                description: 'Alert-Destination.'
                 type: list
                 suboptions:
                     from:
@@ -110,13 +123,13 @@ options:
                             - 'snmp'
                             - 'syslog'
             enable-generic-text:
-                description: no description
+                description: 'Enable/disable generic text match.'
                 type: list
                 choices:
                  - enable
                  - disable
             enable-severity-filter:
-                description: no description
+                description: 'Enable/disable alert severity filter.'
                 type: list
                 choices:
                  - enable
@@ -182,14 +195,14 @@ options:
                     - 'medium-low'
                     - 'low'
             severity-level-comp:
-                description: no description
+                description: 'Log severity threshold comparison criterion.'
                 type: list
                 choices:
-                 - string of >=
-                 - string of =
-                 - string of <=
+                 - >=
+                 - =
+                 - <=
             severity-level-logs:
-                description: no description
+                description: 'Log severity threshold level.'
                 type: list
                 choices:
                  - no-check
@@ -204,7 +217,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -216,35 +229,20 @@ EXAMPLES = '''
     - name: Alert events.
       fmgr_system_alertevent:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         state: <value in [present, absent]>
+         state: present
          system_alertevent:
-            alert-destination:
-              -
-                  from: <value of string>
-                  smtp-name: <value of string>
-                  snmp-name: <value of string>
-                  syslog-name: <value of string>
-                  to: <value of string>
-                  type: <value in [mail, snmp, syslog]>
             enable-generic-text:
               - enable
               - disable
             enable-severity-filter:
               - enable
               - disable
-            event-time-period: <value in [0.5, 1, 3, ...]>
-            generic-text: <value of string>
-            name: <value of string>
-            num-events: <value in [1, 5, 10, ...]>
-            severity-filter: <value in [high, medium-high, medium, ...]>
-            severity-level-comp:
-              - string of >=
-              - string of =
-              - string of <=
+            event-time-period: 1 #<value in [0.5, 1, 3, ...]>
+            name: ansible-test-sysalert
+            num-events: 1 #<value in [1, 5, 10, ...]>
+            severity-filter: high #<value in [high, medium-high, medium, ...]>
+            #severity-level-comp:
+            #  - <=
             severity-level-logs:
               - no-check
               - information
@@ -255,6 +253,23 @@ EXAMPLES = '''
               - alert
               - emergency
 
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the alert events
+      fmgr_fact:
+        facts:
+            selector: 'system_alertevent'
+            params:
+                alert-event: ''
 '''
 
 RETURN = '''
@@ -294,6 +309,25 @@ def main():
     url_params = []
     module_primary_key = 'name'
     module_arg_spec = {
+        'enable_log': {
+            'type': 'bool',
+            'required': False,
+            'default': False
+        },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
+        'proposed_method': {
+            'type': 'str',
+            'required': False,
+            'choices': [
+                'set',
+                'update',
+                'add'
+            ]
+        },
         'bypass_validation': {
             'type': 'bool',
             'required': False,
@@ -327,33 +361,113 @@ def main():
         'system_alertevent': {
             'required': False,
             'type': 'dict',
+            'revision': {
+                '6.0.0': True,
+                '6.2.1': True,
+                '6.2.3': True,
+                '6.2.5': True,
+                '6.4.0': True,
+                '6.4.2': True,
+                '6.4.5': True,
+                '7.0.0': True
+            },
             'options': {
                 'alert-destination': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'type': 'list',
                     'options': {
                         'from': {
                             'required': False,
+                            'revision': {
+                                '6.0.0': True,
+                                '6.2.1': True,
+                                '6.2.3': True,
+                                '6.2.5': True,
+                                '6.4.0': True,
+                                '6.4.2': True,
+                                '6.4.5': True,
+                                '7.0.0': True
+                            },
                             'type': 'str'
                         },
                         'smtp-name': {
                             'required': False,
+                            'revision': {
+                                '6.0.0': True,
+                                '6.2.1': True,
+                                '6.2.3': True,
+                                '6.2.5': True,
+                                '6.4.0': True,
+                                '6.4.2': True,
+                                '6.4.5': True,
+                                '7.0.0': True
+                            },
                             'type': 'str'
                         },
                         'snmp-name': {
                             'required': False,
+                            'revision': {
+                                '6.0.0': True,
+                                '6.2.1': True,
+                                '6.2.3': True,
+                                '6.2.5': True,
+                                '6.4.0': True,
+                                '6.4.2': True,
+                                '6.4.5': True,
+                                '7.0.0': True
+                            },
                             'type': 'str'
                         },
                         'syslog-name': {
                             'required': False,
+                            'revision': {
+                                '6.0.0': True,
+                                '6.2.1': True,
+                                '6.2.3': True,
+                                '6.2.5': True,
+                                '6.4.0': True,
+                                '6.4.2': True,
+                                '6.4.5': True,
+                                '7.0.0': True
+                            },
                             'type': 'str'
                         },
                         'to': {
                             'required': False,
+                            'revision': {
+                                '6.0.0': True,
+                                '6.2.1': True,
+                                '6.2.3': True,
+                                '6.2.5': True,
+                                '6.4.0': True,
+                                '6.4.2': True,
+                                '6.4.5': True,
+                                '7.0.0': True
+                            },
                             'type': 'str'
                         },
                         'type': {
                             'required': False,
+                            'revision': {
+                                '6.0.0': True,
+                                '6.2.1': True,
+                                '6.2.3': True,
+                                '6.2.5': True,
+                                '6.4.0': True,
+                                '6.4.2': True,
+                                '6.4.5': True,
+                                '7.0.0': True
+                            },
                             'choices': [
                                 'mail',
                                 'snmp',
@@ -365,6 +479,16 @@ def main():
                 },
                 'enable-generic-text': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'type': 'list',
                     'choices': [
                         'enable',
@@ -373,6 +497,16 @@ def main():
                 },
                 'enable-severity-filter': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'type': 'list',
                     'choices': [
                         'enable',
@@ -381,6 +515,16 @@ def main():
                 },
                 'event-time-period': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'choices': [
                         '0.5',
                         '1',
@@ -395,14 +539,44 @@ def main():
                 },
                 'generic-text': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'type': 'str'
                 },
                 'name': {
                     'required': True,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'type': 'str'
                 },
                 'num-events': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'choices': [
                         '1',
                         '5',
@@ -414,6 +588,16 @@ def main():
                 },
                 'severity-filter': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'choices': [
                         'high',
                         'medium-high',
@@ -427,13 +611,23 @@ def main():
                     'required': False,
                     'type': 'list',
                     'choices': [
-                        'string of >=',
-                        'string of =',
-                        'string of <='
+                        '>=',
+                        '=',
+                        '<='
                     ]
                 },
                 'severity-level-logs': {
                     'required': False,
+                    'revision': {
+                        '6.0.0': True,
+                        '6.2.1': True,
+                        '6.2.3': True,
+                        '6.2.5': True,
+                        '6.4.0': True,
+                        '6.4.2': True,
+                        '6.4.5': True,
+                        '7.0.0': True
+                    },
                     'type': 'list',
                     'choices': [
                         'no-check',
@@ -459,9 +653,12 @@ def main():
     fmgr = None
     if module._socket_path:
         connection = Connection(module._socket_path)
+        connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
-        fmgr.process_curd()
+        fmgr.process_curd(argument_specs=module_arg_spec)
     else:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     module.exit_json(meta=module.params)
