@@ -5,14 +5,14 @@
 
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
-import json
 import pytest
 
 from ansible.module_utils import basic
-from ansible.module_utils._text import to_bytes
 from ansible_collections.netapp.ontap.tests.unit.compat import unittest
 from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch, Mock, call
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
+from ansible_collections.netapp.ontap.tests.unit.plugins.module_utils.ansible_mocks import set_module_args,\
+    AnsibleFailJson, AnsibleExitJson, patch_ansible, assert_warning_was_raised, assert_no_warnings, print_warnings
 
 from ansible_collections.netapp.ontap.plugins.modules.na_ontap_igroup \
     import NetAppOntapIgroup as igroup  # module under test
@@ -37,39 +37,13 @@ SRR = {
         dict(uuid='a1b2c3',
              name='test',
              svm=dict(name='vserver'),
+             initiators=[{'name': 'todelete'}],
              protocol='fcp',
              os_type='aix')
     ], num_records=1), None),
 }
 
 
-def set_module_args(args):
-    """prepare arguments so that they will be picked up during module creation"""
-    args = json.dumps({'ANSIBLE_MODULE_ARGS': args})
-    basic._ANSIBLE_ARGS = to_bytes(args)  # pylint: disable=protected-access
-
-
-class AnsibleExitJson(Exception):
-    """Exception class to be raised by module.exit_json and caught by the test case"""
-
-
-class AnsibleFailJson(Exception):
-    """Exception class to be raised by module.fail_json and caught by the test case"""
-
-
-def exit_json(*args, **kwargs):  # pylint: disable=unused-argument
-    """function to patch over exit_json; package return data into an exception"""
-    if 'changed' not in kwargs:
-        kwargs['changed'] = False
-    raise AnsibleExitJson(kwargs)
-
-
-def fail_json(*args, **kwargs):  # pylint: disable=unused-argument
-    """function to patch over fail_json; package return data into an exception"""
-    kwargs['failed'] = True
-    raise AnsibleFailJson(kwargs)
-
-
 class MockONTAPConnection(object):
     ''' mock server connection to ONTAP host '''
 
@@ -136,19 +110,6 @@ class TestMyModule(unittest.TestCase):
     ''' a group of related Unit Tests '''
 
     def setUp(self):
-        self.warnings = list()
-
-        def log(other_self, msg, log_args=None):  # pylint: disable=unused-argument
-            if msg.startswith('Invoked with'):
-                return
-            self.warnings.append(msg)
-
-        self.mock_module_helper = patch.multiple(basic.AnsibleModule,
-                                                 exit_json=exit_json,
-                                                 fail_json=fail_json,
-                                                 log=log)
-        self.mock_module_helper.start()
-        self.addCleanup(self.mock_module_helper.stop)
         self.server = MockONTAPConnection()
 
     def mock_args(self, use_rest='never'):
@@ -333,6 +294,7 @@ class TestMyModule(unittest.TestCase):
         mock_request.side_effect = [
             SRR['is_rest'],
             SRR['one_igroup_record'],   # get
+            SRR['empty_good'],          # post (remove initiators)
             SRR['empty_good'],          # post (add initiators)
             SRR['empty_good'],          # patch (modify os_type)
             SRR['end_of_sequence']
@@ -347,16 +309,16 @@ class TestMyModule(unittest.TestCase):
         assert expected_call in mock_request.mock_calls
 
     @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
-    def test_successful_modify_igroups_rest(self, mock_request):
+    def test_successful_modify_initiator_objects_rest(self, mock_request):
         ''' Test successful modify '''
-        data = dict(self.mock_args())
+        data = dict(self.mock_args('always'))
         data.pop('initiator_names')
-        data['igroups'] = ['test_igroup']
-        data['use_rest'] = 'auto'
+        data['initiator_objects'] = [{'name': 'init1', 'comment': 'comment1'}]
         set_module_args(data)
         mock_request.side_effect = [
             SRR['is_rest_9_9_1'],
             SRR['one_igroup_record'],   # get
+            SRR['empty_good'],          # post (remove initiators)
             SRR['empty_good'],          # post (add initiators)
             SRR['empty_good'],          # patch (modify os_type)
             SRR['end_of_sequence']
@@ -364,6 +326,58 @@ class TestMyModule(unittest.TestCase):
         with pytest.raises(AnsibleExitJson) as exc:
             igroup().apply()
         assert exc.value.args[0]['changed']
+        print(mock_request.mock_calls)
+        expected_call = call('POST', 'protocols/san/igroups/a1b2c3/initiators', None,
+                             json={'records': [{'name': 'init1', 'comment': 'comment1'}]}, headers=None)
+        assert expected_call in mock_request.mock_calls
+        expected_call = call('PATCH', 'protocols/san/igroups/a1b2c3', None, json={'os_type': 'linux'}, headers=None)
+        assert expected_call in mock_request.mock_calls
+
+    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
+    def test_successful_modify_initiator_objects_comment_rest(self, mock_request):
+        ''' Test successful modify '''
+        data = dict(self.mock_args('always'))
+        data.pop('initiator_names')
+        data['initiator_objects'] = [{'name': 'todelete', 'comment': 'comment1'}]
+        set_module_args(data)
+        mock_request.side_effect = [
+            SRR['is_rest_9_9_1'],
+            SRR['one_igroup_record'],   # get
+            # SRR['empty_good'],          # post (remove initiators)
+            SRR['empty_good'],          # post (add initiators)
+            SRR['empty_good'],          # patch (modify os_type)
+            SRR['end_of_sequence']
+        ]
+        with pytest.raises(AnsibleExitJson) as exc:
+            igroup().apply()
+        assert exc.value.args[0]['changed']
+        print(mock_request.mock_calls)
+        expected_call = call('PATCH', 'protocols/san/igroups/a1b2c3/initiators/todelete', None, json={'comment': 'comment1'}, headers=None)
+        assert expected_call in mock_request.mock_calls
+        expected_call = call('PATCH', 'protocols/san/igroups/a1b2c3', None, json={'os_type': 'linux'}, headers=None)
+        assert expected_call in mock_request.mock_calls
+
+    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
+    def test_successful_modify_igroups_rest(self, mock_request):
+        ''' Test successful modify '''
+        data = dict(self.mock_args())
+        data.pop('initiator_names')
+        data['igroups'] = ['test_igroup']
+        data['use_rest'] = 'auto'
+        data['force_remove_initiator'] = True
+        set_module_args(data)
+        mock_request.side_effect = [
+            SRR['is_rest_9_9_1'],
+            SRR['one_igroup_record'],   # get
+            SRR['empty_good'],          # post (remove initiators)
+            SRR['empty_good'],          # post (add initiators)
+            SRR['empty_good'],          # patch (modify os_type)
+            SRR['end_of_sequence']
+        ]
+        with pytest.raises(AnsibleExitJson) as exc:
+            igroup().apply()
+        print(mock_request.mock_calls)
+        assert exc.value.args[0]['changed']
 
     @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
     def test_9_9_0_no_igroups_rest(self, mock_request):
@@ -415,6 +429,7 @@ class TestMyModule(unittest.TestCase):
             SRR['is_rest'],
             SRR['zero_record'],         # get
             SRR['one_igroup_record'],   # get
+            SRR['empty_good'],          # post for remove initiator
             SRR['empty_good'],          # post for add initiator
             SRR['empty_good'],          # patch for rename
             SRR['end_of_sequence']
@@ -441,7 +456,8 @@ class TestMyModule(unittest.TestCase):
             obj.apply()
         assert exc.value.args[0]['changed']
         msg = "Warning: falling back to ZAPI: using bind_portset requires ONTAP 9.9 or later and REST must be enabled - ONTAP version: 9.8.0."
-        assert msg in self.warnings[-1]
+        print_warnings()
+        assert_warning_was_raised(msg)
 
     @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
     def test_positive_zapi_or_rest99_option(self, mock_request):
@@ -458,8 +474,8 @@ class TestMyModule(unittest.TestCase):
             obj.apply()
         assert exc.value.args[0]['changed']
         msg = "Warning: falling back to ZAPI: using bind_portset requires ONTAP 9.9 or later and REST must be enabled - ONTAP version: 9.8.0."
-        print(self.warnings)
-        assert msg in self.warnings[-1]
+        print_warnings()
+        assert_warning_was_raised(msg)
 
     @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.OntapRestAPI.send_request')
     def test_create_rest_99(self, mock_request):
@@ -477,8 +493,8 @@ class TestMyModule(unittest.TestCase):
         with pytest.raises(AnsibleExitJson) as exc:
             obj.apply()
         assert exc.value.args[0]['changed']
-        print(self.warnings)
-        assert not self.warnings
+        print_warnings
+        assert_no_warnings()
         expected_json = {'name': 'test', 'os_type': 'linux', 'svm': {'name': 'vserver'}, 'protocol': 'fcp', 'portset': 'my_portset',
                          'initiators': [{'name': 'init1'}]}
         expected_call = call('POST', 'protocols/san/igroups', None, json=expected_json, headers=None)
