@@ -5,15 +5,14 @@
 
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
-import json
 import sys
 import pytest
 
 from ansible_collections.netapp.ontap.tests.unit.compat import unittest
 from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch, Mock
-from ansible.module_utils import basic
-from ansible.module_utils._text import to_bytes
 from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch
+from ansible_collections.netapp.ontap.tests.unit.plugins.module_utils.ansible_mocks import set_module_args,\
+    AnsibleFailJson, AnsibleExitJson, patch_ansible
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
 
 from ansible_collections.netapp.ontap.plugins.modules.na_ontap_license \
@@ -28,33 +27,6 @@ if not netapp_utils.HAS_REQUESTS and sys.version_info < (2, 7):
     pytestmark = pytest.mark.skip('Skipping Unit Tests on 2.6 as requests is not be available')
 
 
-def set_module_args(args):
-    """prepare arguments so that they will be picked up during module creation"""
-    args = json.dumps({'ANSIBLE_MODULE_ARGS': args})
-    basic._ANSIBLE_ARGS = to_bytes(args)  # pylint: disable=protected-access
-
-
-class AnsibleExitJson(Exception):
-    """Exception class to be raised by module.exit_json and caught by the test case"""
-
-
-class AnsibleFailJson(Exception):
-    """Exception class to be raised by module.fail_json and caught by the test case"""
-
-
-def exit_json(*args, **kwargs):  # pylint: disable=unused-argument
-    """function to patch over exit_json; package return data into an exception"""
-    if 'changed' not in kwargs:
-        kwargs['changed'] = False
-    raise AnsibleExitJson(kwargs)
-
-
-def fail_json(*args, **kwargs):  # pylint: disable=unused-argument
-    """function to patch over fail_json; package return data into an exception"""
-    kwargs['failed'] = True
-    raise AnsibleFailJson(kwargs)
-
-
 class MockONTAPConnection(object):
     ''' mock server connection to ONTAP host '''
 
@@ -80,11 +52,6 @@ class TestMyModule(unittest.TestCase):
     ''' a group of related Unit Tests '''
 
     def setUp(self):
-        self.mock_module_helper = patch.multiple(basic.AnsibleModule,
-                                                 exit_json=exit_json,
-                                                 fail_json=fail_json)
-        self.mock_module_helper.start()
-        self.addCleanup(self.mock_module_helper.stop)
         self.server = MockONTAPConnection()
 
     def mock_args(self):
@@ -93,7 +60,8 @@ class TestMyModule(unittest.TestCase):
             'username': 'test_user',
             'password': 'test_pass!',
             'use_rest': 'never',
-            'state': 'present'
+            'state': 'present',
+            'feature_flags': {'no_cserver_ems': True}
         }
 
     def get_license_mock_object(self, kind=None, data=None):
@@ -107,12 +75,7 @@ class TestMyModule(unittest.TestCase):
         license_obj.asup_log_for_cserver = Mock(return_value=None)
         license_obj.cluster = Mock()
         license_obj.cluster.invoke_successfully = Mock()
-        if kind is None:
-            license_obj.server = MockONTAPConnection()
-        elif kind == 'generic-error':
-            license_obj.server = MockONTAPConnection(kind=kind)
-        elif kind == 'entry-not-exist':
-            license_obj.server = MockONTAPConnection(kind=kind)
+        license_obj.server = MockONTAPConnection(kind=kind)
         return license_obj
 
     @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_license.NetAppOntapLicense.get_licensing_status')
@@ -355,18 +318,6 @@ SRR = {
 }
 
 
-# using pytest natively, without unittest.TestCase
-@pytest.fixture
-def patch_ansible():
-    with patch.multiple(basic.AnsibleModule,
-                        exit_json=exit_json,
-                        fail_json=fail_json,
-                        warn=warn) as mocks:
-        global WARNINGS
-        WARNINGS = []
-        yield mocks
-
-
 def test_module_fail_when_unsupported_rest_present(patch_ansible):
     ''' error if unsupported rest properties present '''
     args = dict(default_args())
