@@ -7,14 +7,13 @@ from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
 import sys
-import json
 import pytest
 
 from ansible_collections.netapp.ontap.tests.unit.compat import unittest
 from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch, Mock
-from ansible.module_utils import basic
-from ansible.module_utils._text import to_bytes
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
+from ansible_collections.netapp.ontap.tests.unit.plugins.module_utils.ansible_mocks import set_module_args,\
+    AnsibleFailJson, AnsibleExitJson, patch_ansible
 
 from ansible_collections.netapp.ontap.plugins.modules.na_ontap_vserver_peer \
     import NetAppONTAPVserverPeer as vserver_peer, main as uut_main  # module under test
@@ -23,35 +22,6 @@ if not netapp_utils.has_netapp_lib():
     pytestmark = pytest.mark.skip('skipping as missing required netapp_lib')
 
 
-def set_module_args(args):
-    """prepare arguments so that they will be picked up during module creation"""
-    args = json.dumps({'ANSIBLE_MODULE_ARGS': args})
-    basic._ANSIBLE_ARGS = to_bytes(args)  # pylint: disable=protected-access
-
-
-class AnsibleExitJson(Exception):
-    """Exception class to be raised by module.exit_json and caught by the test case"""
-    pass
-
-
-class AnsibleFailJson(Exception):
-    """Exception class to be raised by module.fail_json and caught by the test case"""
-    pass
-
-
-def exit_json(*args, **kwargs):  # pylint: disable=unused-argument
-    """function to patch over exit_json; package return data into an exception"""
-    if 'changed' not in kwargs:
-        kwargs['changed'] = False
-    raise AnsibleExitJson(kwargs)
-
-
-def fail_json(*args, **kwargs):  # pylint: disable=unused-argument
-    """function to patch over fail_json; package return data into an exception"""
-    kwargs['failed'] = True
-    raise AnsibleFailJson(kwargs)
-
-
 class MockONTAPConnection(object):
     ''' mock server connection to ONTAP host '''
 
@@ -65,10 +35,13 @@ class MockONTAPConnection(object):
     def invoke_successfully(self, xml, enable_tunneling):  # pylint: disable=unused-argument
         ''' mock invoke_successfully returning xml data '''
         self.xml_in = xml
+        print('IN:', xml.to_string())
         if self.kind == 'vserver_peer':
             xml = self.build_vserver_peer_info(self.data)
         if self.kind == 'cluster':
             xml = self.build_cluster_info(self.data)
+        if self.kind == 'zapi_error':
+            raise netapp_utils.zapi.NaApiError(code='TEST', message="This exception is from the unit test")
         self.xml_out = xml
         return xml
 
@@ -111,11 +84,6 @@ class TestMyModule(unittest.TestCase):
     ''' a group of related Unit Tests '''
 
     def setUp(self):
-        self.mock_module_helper = patch.multiple(basic.AnsibleModule,
-                                                 exit_json=exit_json,
-                                                 fail_json=fail_json)
-        self.mock_module_helper.start()
-        self.addCleanup(self.mock_module_helper.stop)
         self.mock_vserver_peer = {
             'vserver': 'test',
             'peer_vserver': 'test_peer',
@@ -127,6 +95,8 @@ class TestMyModule(unittest.TestCase):
             'dest_hostname': 'hostname',
             'username': 'username',
             'password': 'password',
+            'feature_flags': {'no_cserver_ems': True},
+            'use_rest': 'never'
 
         }
 
@@ -309,7 +279,7 @@ class TestMyModule(unittest.TestCase):
         data = dict(self.mock_vserver_peer)
         set_module_args(data)
         with pytest.raises(AnsibleFailJson) as exc:
-            uut_main()
+            self.get_vserver_peer_mock_object('zapi_error').apply()
         msg = "Error fetching vserver peer"
         assert msg in exc.value.args[0]['msg']
 
@@ -408,18 +378,6 @@ SRR = {
 }
 
 
-# using pytest natively, without unittest.TestCase
-@pytest.fixture
-def patch_ansible():
-    with patch.multiple(basic.AnsibleModule,
-                        exit_json=exit_json,
-                        fail_json=fail_json,
-                        warn=warn) as mocks:
-        global WARNINGS
-        WARNINGS = []
-        yield mocks
-
-
 def test_module_fail_when_required_args_missing(patch_ansible):
     ''' required arguments are reported as errors '''
     args = dict(default_args())
